@@ -1,28 +1,18 @@
 # ActivitySim
 # See full license in LICENSE.txt.
-from builtins import range
-
 import logging
+from builtins import range
 
 import numpy as np
 import pandas as pd
 
-from activitysim.core import logit
-from activitysim.core import config
-from activitysim.core import inject
-from activitysim.core import tracing
-from activitysim.core import chunk
-from activitysim.core import pipeline
-
+from activitysim.abm.models.util import estimation
+from activitysim.abm.models.util.trip import cleanup_failed_trips, failed_trip_cohorts
+from activitysim.core import chunk, config, inject, logit, pipeline, tracing
 from activitysim.core.util import reindex
 
-from activitysim.abm.models.util.trip import failed_trip_cohorts
-from activitysim.abm.models.util.trip import cleanup_failed_trips
-
-from activitysim.abm.models.util import estimation
 from .util import probabilistic_scheduling as ps
 
-
 logger = logging.getLogger(__name__)
 
 """
@@ -36,17 +26,22 @@ tourpurp,isInbound,interval,trip,p1,p2,p3,p4,p5...p40
 NO_TRIP_ID = 0
 NO_DEPART = 0
 
-DEPART_ALT_BASE = 'DEPART_ALT_BASE'
+DEPART_ALT_BASE = "DEPART_ALT_BASE"
 
-FAILFIX = 'FAILFIX'
-FAILFIX_CHOOSE_MOST_INITIAL = 'choose_most_initial'
-FAILFIX_DROP_AND_CLEANUP = 'drop_and_cleanup'
+FAILFIX = "FAILFIX"
+FAILFIX_CHOOSE_MOST_INITIAL = "choose_most_initial"
+FAILFIX_DROP_AND_CLEANUP = "drop_and_cleanup"
 FAILFIX_DEFAULT = FAILFIX_CHOOSE_MOST_INITIAL
 
-DEPARTURE_MODE = 'departure'
-DURATION_MODE = 'stop_duration'
-PROBS_JOIN_COLUMNS_DEPARTURE_BASED = ['primary_purpose', 'outbound', 'tour_hour', 'trip_num']
-PROBS_JOIN_COLUMNS_DURATION_BASED = ['outbound', 'stop_num']
+DEPARTURE_MODE = "departure"
+DURATION_MODE = "stop_duration"
+PROBS_JOIN_COLUMNS_DEPARTURE_BASED = [
+    "primary_purpose",
+    "outbound",
+    "tour_hour",
+    "trip_num",
+]
+PROBS_JOIN_COLUMNS_DURATION_BASED = ["outbound", "stop_num"]
 
 
 def set_tour_hour(trips, tours):
@@ -64,33 +59,37 @@ def set_tour_hour(trips, tours):
     """
 
     # all trips must depart between tour start and end
-    trips['earliest'] = reindex(tours.start, trips.tour_id)
-    trips['latest'] = reindex(tours.end, trips.tour_id)
+    trips["earliest"] = reindex(tours.start, trips.tour_id)
+    trips["latest"] = reindex(tours.end, trips.tour_id)
 
     # tour_hour is start for outbound trips, and end for inbound trips
-    trips['tour_hour'] = np.where(
-        trips.outbound,
-        trips['earliest'],
-        trips['latest']).astype(np.int8)
+    trips["tour_hour"] = np.where(
+        trips.outbound, trips["earliest"], trips["latest"]
+    ).astype(np.int8)
 
     # subtours indexed by parent_tour_id
-    subtours = tours.loc[tours.primary_purpose == 'atwork',
-                         ['tour_num', 'tour_count', 'parent_tour_id', 'start', 'end']]
+    subtours = tours.loc[
+        tours.primary_purpose == "atwork",
+        ["tour_num", "tour_count", "parent_tour_id", "start", "end"],
+    ]
 
     subtours.parent_tour_id = subtours.parent_tour_id.astype(np.int64)
-    subtours = subtours.set_index('parent_tour_id')
+    subtours = subtours.set_index("parent_tour_id")
     subtours = subtours.astype(np.int16)  # remaining columns are all small ints
 
     # bool series
     trip_has_subtours = trips.tour_id.isin(subtours.index)
 
     outbound = trip_has_subtours & trips.outbound
-    trips.loc[outbound, 'latest'] = \
-        reindex(subtours[subtours.tour_num == 1]['start'], trips[outbound].tour_id)
+    trips.loc[outbound, "latest"] = reindex(
+        subtours[subtours.tour_num == 1]["start"], trips[outbound].tour_id
+    )
 
     inbound = trip_has_subtours & ~trips.outbound
-    trips.loc[inbound, 'earliest'] = \
-        reindex(subtours[subtours.tour_num == subtours.tour_count]['end'], trips[inbound].tour_id)
+    trips.loc[inbound, "earliest"] = reindex(
+        subtours[subtours.tour_num == subtours.tour_count]["end"],
+        trips[inbound].tour_id,
+    )
 
 
 def set_stop_num(trips):
@@ -102,8 +101,8 @@ def set_stop_num(trips):
     outbound trips technically choose a departure time while inbound trips
     choose an arrival.
     """
-    trips['stop_num'] = trips['trip_num'] - 1
-    trips['stop_num'] = trips.stop_num.where(trips['outbound'], trips['trip_num'])
+    trips["stop_num"] = trips["trip_num"] - 1
+    trips["stop_num"] = trips.stop_num.where(trips["outbound"], trips["trip_num"])
 
 
 def update_tour_earliest(trips, outbound_choices):
@@ -125,35 +124,41 @@ def update_tour_earliest(trips, outbound_choices):
     """
     # append outbound departure times to trips
     tmp_trips = trips.copy()
-    tmp_trips['outbound_departure'] = outbound_choices.reindex(tmp_trips.index)
+    tmp_trips["outbound_departure"] = outbound_choices.reindex(tmp_trips.index)
 
     # get max outbound trip departure times for all person-tours
-    max_outbound_person_departures = tmp_trips.groupby(
-        ['person_id', 'tour_id'])['outbound_departure'].max()
-    max_outbound_person_departures.name = 'max_outbound_departure'
+    max_outbound_person_departures = tmp_trips.groupby(["person_id", "tour_id"])[
+        "outbound_departure"
+    ].max()
+    max_outbound_person_departures.name = "max_outbound_departure"
 
     # append max outbound trip departure times to trips
     tmp_trips = tmp_trips.merge(
         max_outbound_person_departures,
-        left_on=['person_id', 'tour_id'], right_index=True)
+        left_on=["person_id", "tour_id"],
+        right_index=True,
+    )
 
     # set the trips "earliest" column equal to the max outbound departure
     # time for all inbound trips. preserve values that were used for outbound trips
-    tmp_trips['earliest'] = tmp_trips['earliest'].where(
-        tmp_trips['outbound'], tmp_trips['max_outbound_departure'])
+    tmp_trips["earliest"] = tmp_trips["earliest"].where(
+        tmp_trips["outbound"], tmp_trips["max_outbound_departure"]
+    )
 
-    trips['earliest'] = tmp_trips['earliest'].reindex(trips.index)
+    trips["earliest"] = tmp_trips["earliest"].reindex(trips.index)
 
     return
 
 
 def schedule_trips_in_leg(
-        outbound,
-        trips,
-        probs_spec,
-        model_settings,
-        is_last_iteration,
-        trace_hh_id, trace_label):
+    outbound,
+    trips,
+    probs_spec,
+    model_settings,
+    is_last_iteration,
+    trace_hh_id,
+    trace_label,
+):
     """
 
     Parameters
@@ -173,17 +178,22 @@ def schedule_trips_in_leg(
     """
 
     failfix = model_settings.get(FAILFIX, FAILFIX_DEFAULT)
-    depart_alt_base = model_settings.get('DEPART_ALT_BASE', 0)
-    scheduling_mode = model_settings.get('scheduling_mode', 'departure')
+    depart_alt_base = model_settings.get("DEPART_ALT_BASE", 0)
+    scheduling_mode = model_settings.get("scheduling_mode", "departure")
 
-    if scheduling_mode == 'departure':
-        probs_join_cols = model_settings.get('probs_join_cols', PROBS_JOIN_COLUMNS_DEPARTURE_BASED)
-    elif scheduling_mode == 'stop_duration':
-        probs_join_cols = model_settings.get('probs_join_cols', PROBS_JOIN_COLUMNS_DURATION_BASED)
+    if scheduling_mode == "departure":
+        probs_join_cols = model_settings.get(
+            "probs_join_cols", PROBS_JOIN_COLUMNS_DEPARTURE_BASED
+        )
+    elif scheduling_mode == "stop_duration":
+        probs_join_cols = model_settings.get(
+            "probs_join_cols", PROBS_JOIN_COLUMNS_DURATION_BASED
+        )
     else:
         logger.error(
             "Invalid scheduling mode specified: {0}.".format(scheduling_mode),
-            "Please select one of ['departure', 'stop_duration'] and try again.")
+            "Please select one of ['departure', 'stop_duration'] and try again.",
+        )
 
     # logger.debug("%s scheduling %s trips" % (trace_label, trips.shape[0]))
 
@@ -194,8 +204,10 @@ def schedule_trips_in_leg(
 
     # trips to/from tour origin or atwork get tour_hour departure times
     # no need to schedule them if there are no intermediate stops
-    to_from_tour_orig = (trips.trip_num == 1) if outbound else (trips.trip_num == trips.trip_count)
-    do_not_schedule = to_from_tour_orig | (trips.primary_purpose == 'atwork')
+    to_from_tour_orig = (
+        (trips.trip_num == 1) if outbound else (trips.trip_num == trips.trip_count)
+    )
+    do_not_schedule = to_from_tour_orig | (trips.primary_purpose == "atwork")
     choices = trips.tour_hour[do_not_schedule]
 
     if do_not_schedule.all():
@@ -207,16 +219,16 @@ def schedule_trips_in_leg(
     # add next_trip_id temp column, and specificy departure constraint column to update
     trips = trips.sort_index()
     if outbound or scheduling_mode == DURATION_MODE:
-        trips['next_trip_id'] = np.roll(trips.index, -1)
+        trips["next_trip_id"] = np.roll(trips.index, -1)
         is_final = trips.trip_num == trips.trip_count
         # each trip's depart constrains next trip's earliest depart option
-        ADJUST_NEXT_DEPART_COL = 'earliest'
+        ADJUST_NEXT_DEPART_COL = "earliest"
     else:
-        trips['next_trip_id'] = np.roll(trips.index, 1)
+        trips["next_trip_id"] = np.roll(trips.index, 1)
         is_final = trips.trip_num == 1
         # if inbound, we are handling in reverse order, so each choice
         # constrains latest depart of the preceding trip
-        ADJUST_NEXT_DEPART_COL = 'latest'
+        ADJUST_NEXT_DEPART_COL = "latest"
     trips.next_trip_id = trips.next_trip_id.where(~is_final, NO_TRIP_ID)
 
     first_trip_in_leg = True
@@ -229,34 +241,43 @@ def schedule_trips_in_leg(
             # iterate over inbound trips in descending trip_num order, skipping the final trip
             nth_trips = trips[trips.trip_num == trips.trip_count - i]
 
-        nth_trace_label = tracing.extend_trace_label(trace_label, 'num_%s' % i)
+        nth_trace_label = tracing.extend_trace_label(trace_label, "num_%s" % i)
 
         choices = ps.make_scheduling_choices(
-            nth_trips, scheduling_mode, probs_spec, probs_join_cols,
+            nth_trips,
+            scheduling_mode,
+            probs_spec,
+            probs_join_cols,
             depart_alt_base,
             first_trip_in_leg=first_trip_in_leg,
             report_failed_trips=is_last_iteration,
             trace_hh_id=trace_hh_id,
-            trace_label=nth_trace_label)
+            trace_label=nth_trace_label,
+        )
 
         # most initial departure (when no choice was made because all probs were zero)
         if is_last_iteration and (failfix == FAILFIX_CHOOSE_MOST_INITIAL):
             choices = choices.reindex(nth_trips.index)
-            logger.warning("%s coercing %s depart choices to most initial" %
-                           (nth_trace_label, choices.isna().sum()))
+            logger.warning(
+                "%s coercing %s depart choices to most initial"
+                % (nth_trace_label, choices.isna().sum())
+            )
             choices = choices.fillna(trips[ADJUST_NEXT_DEPART_COL])
 
         # adjust allowed depart range of next trip
-        has_next_trip = (nth_trips.next_trip_id != NO_TRIP_ID)
+        has_next_trip = nth_trips.next_trip_id != NO_TRIP_ID
         if has_next_trip.any():
             next_trip_ids = nth_trips.next_trip_id[has_next_trip]
             # patch choice any trips with next_trips that weren't scheduled
-            trips.loc[next_trip_ids, ADJUST_NEXT_DEPART_COL] = \
-                choices.reindex(next_trip_ids.index).fillna(trips[ADJUST_NEXT_DEPART_COL]).values
+            trips.loc[next_trip_ids, ADJUST_NEXT_DEPART_COL] = (
+                choices.reindex(next_trip_ids.index)
+                .fillna(trips[ADJUST_NEXT_DEPART_COL])
+                .values
+            )
 
         result_list.append(choices)
 
-        chunk.log_df(trace_label, f'result_list', result_list)
+        chunk.log_df(trace_label, f"result_list", result_list)
 
         first_trip_in_leg = False
 
@@ -267,15 +288,16 @@ def schedule_trips_in_leg(
 
 
 def run_trip_scheduling(
-        trips_chunk,
-        tours,
-        probs_spec,
-        model_settings,
-        estimator,
-        is_last_iteration,
-        chunk_size,
-        trace_hh_id,
-        trace_label):
+    trips_chunk,
+    tours,
+    probs_spec,
+    model_settings,
+    estimator,
+    is_last_iteration,
+    chunk_size,
+    trace_hh_id,
+    trace_label,
+):
 
     set_tour_hour(trips_chunk, tours)
     set_stop_num(trips_chunk)
@@ -289,19 +311,19 @@ def run_trip_scheduling(
 
     if trips_chunk.outbound.any():
         leg_chunk = trips_chunk[trips_chunk.outbound]
-        leg_trace_label = tracing.extend_trace_label(trace_label, 'outbound')
-        choices = \
-            schedule_trips_in_leg(
-                outbound=True,
-                trips=leg_chunk,
-                probs_spec=probs_spec,
-                model_settings=model_settings,
-                is_last_iteration=is_last_iteration,
-                trace_hh_id=trace_hh_id,
-                trace_label=leg_trace_label)
+        leg_trace_label = tracing.extend_trace_label(trace_label, "outbound")
+        choices = schedule_trips_in_leg(
+            outbound=True,
+            trips=leg_chunk,
+            probs_spec=probs_spec,
+            model_settings=model_settings,
+            is_last_iteration=is_last_iteration,
+            trace_hh_id=trace_hh_id,
+            trace_label=leg_trace_label,
+        )
         result_list.append(choices)
 
-        chunk.log_df(trace_label, f'result_list', result_list)
+        chunk.log_df(trace_label, f"result_list", result_list)
 
         # departure time of last outbound trips must constrain
         # departure times for initial inbound trips
@@ -309,19 +331,19 @@ def run_trip_scheduling(
 
     if (~trips_chunk.outbound).any():
         leg_chunk = trips_chunk[~trips_chunk.outbound]
-        leg_trace_label = tracing.extend_trace_label(trace_label, 'inbound')
-        choices = \
-            schedule_trips_in_leg(
-                outbound=False,
-                trips=leg_chunk,
-                probs_spec=probs_spec,
-                model_settings=model_settings,
-                is_last_iteration=is_last_iteration,
-                trace_hh_id=trace_hh_id,
-                trace_label=leg_trace_label)
+        leg_trace_label = tracing.extend_trace_label(trace_label, "inbound")
+        choices = schedule_trips_in_leg(
+            outbound=False,
+            trips=leg_chunk,
+            probs_spec=probs_spec,
+            model_settings=model_settings,
+            is_last_iteration=is_last_iteration,
+            trace_hh_id=trace_hh_id,
+            trace_label=leg_trace_label,
+        )
         result_list.append(choices)
 
-        chunk.log_df(trace_label, f'result_list', result_list)
+        chunk.log_df(trace_label, f"result_list", result_list)
 
     choices = pd.concat(result_list)
 
@@ -329,11 +351,7 @@ def run_trip_scheduling(
 
 
 @inject.step()
-def trip_scheduling(
-        trips,
-        tours,
-        chunk_size,
-        trace_hh_id):
+def trip_scheduling(trips, tours, chunk_size, trace_hh_id):
 
     """
     Trip scheduling assigns depart times for trips within the start, end limits of the tour.
@@ -381,7 +399,7 @@ def trip_scheduling(
 
     """
     trace_label = "trip_scheduling"
-    model_settings_file_name = 'trip_scheduling.yaml'
+    model_settings_file_name = "trip_scheduling.yaml"
     model_settings = config.read_model_settings(model_settings_file_name)
 
     trips_df = trips.to_frame()
@@ -392,35 +410,52 @@ def trip_scheduling(
 
     # trip_scheduling is a probabilistic model ane we don't support estimation,
     # but we do need to override choices in estimation mode
-    estimator = estimation.manager.begin_estimation('trip_scheduling')
+    estimator = estimation.manager.begin_estimation("trip_scheduling")
     if estimator:
-        estimator.write_spec(model_settings, tag='PROBS_SPEC')
+        estimator.write_spec(model_settings, tag="PROBS_SPEC")
         estimator.write_model_settings(model_settings, model_settings_file_name)
-        chooser_cols_for_estimation = ['person_id',  'household_id',  'tour_id',  'trip_num', 'trip_count',
-                                       'primary_purpose', 'outbound', 'earliest', 'latest', 'tour_hour', ]
+        chooser_cols_for_estimation = [
+            "person_id",
+            "household_id",
+            "tour_id",
+            "trip_num",
+            "trip_count",
+            "primary_purpose",
+            "outbound",
+            "earliest",
+            "latest",
+            "tour_hour",
+        ]
         estimator.write_choosers(trips_df[chooser_cols_for_estimation])
 
-    probs_spec = pd.read_csv(config.config_file_path('trip_scheduling_probs.csv'), comment='#')
+    probs_spec = pd.read_csv(
+        config.config_file_path("trip_scheduling_probs.csv"), comment="#"
+    )
     # FIXME for now, not really doing estimation for probabilistic model - just overwriting choices
     # besides, it isn't clear that named coefficients would be helpful if we had some form of estimation
     # coefficients_df = simulate.read_model_coefficients(model_settings)
     # probs_spec = map_coefficients(probs_spec, coefficients_df)
 
     # add tour-based chunk_id so we can chunk all trips in tour together
-    trips_df['chunk_id'] = reindex(pd.Series(list(range(len(tours))), tours.index), trips_df.tour_id)
+    trips_df["chunk_id"] = reindex(
+        pd.Series(list(range(len(tours))), tours.index), trips_df.tour_id
+    )
 
-    assert 'DEPART_ALT_BASE' in model_settings
+    assert "DEPART_ALT_BASE" in model_settings
     failfix = model_settings.get(FAILFIX, FAILFIX_DEFAULT)
 
-    max_iterations = model_settings.get('MAX_ITERATIONS', 1)
+    max_iterations = model_settings.get("MAX_ITERATIONS", 1)
     assert max_iterations > 0
 
     choices_list = []
 
-    for chunk_i, trips_chunk, chunk_trace_label in chunk.adaptive_chunked_choosers_by_chunk_id(trips_df,
-                                                                                               chunk_size,
-                                                                                               trace_label,
-                                                                                               trace_label):
+    for (
+        chunk_i,
+        trips_chunk,
+        chunk_trace_label,
+    ) in chunk.adaptive_chunked_choosers_by_chunk_id(
+        trips_df, chunk_size, trace_label, trace_label
+    ):
 
         i = 0
         while (i < max_iterations) and not trips_chunk.empty:
@@ -429,22 +464,27 @@ def trip_scheduling(
             with chunk.chunk_log(trace_label) if i == 0 else chunk.chunk_log_skip():
 
                 i += 1
-                is_last_iteration = (i == max_iterations)
+                is_last_iteration = i == max_iterations
 
                 trace_label_i = tracing.extend_trace_label(trace_label, "i%s" % i)
-                logger.info("%s scheduling %s trips within chunk %s", trace_label_i, trips_chunk.shape[0], chunk_i)
+                logger.info(
+                    "%s scheduling %s trips within chunk %s",
+                    trace_label_i,
+                    trips_chunk.shape[0],
+                    chunk_i,
+                )
 
-                choices = \
-                    run_trip_scheduling(
-                        trips_chunk,
-                        tours,
-                        probs_spec,
-                        model_settings,
-                        estimator=estimator,
-                        is_last_iteration=is_last_iteration,
-                        chunk_size=chunk_size,
-                        trace_hh_id=trace_hh_id,
-                        trace_label=trace_label_i)
+                choices = run_trip_scheduling(
+                    trips_chunk,
+                    tours,
+                    probs_spec,
+                    model_settings,
+                    estimator=estimator,
+                    is_last_iteration=is_last_iteration,
+                    chunk_size=chunk_size,
+                    trace_hh_id=trace_hh_id,
+                    trace_label=trace_label_i,
+                )
 
                 # boolean series of trips whose individual trip scheduling failed
                 failed = choices.reindex(trips_chunk.index).isnull()
@@ -465,24 +505,30 @@ def trip_scheduling(
 
     if estimator:
         estimator.write_choices(choices)
-        choices = estimator.get_survey_values(choices, 'trips', 'depart')  # override choices
+        choices = estimator.get_survey_values(
+            choices, "trips", "depart"
+        )  # override choices
         estimator.write_override_choices(choices)
         estimator.end_estimation()
         assert not choices.isnull().any()
 
     if choices.isnull().any():
-        logger.warning("%s of %s trips could not be scheduled after %s iterations" %
-                       (choices.isnull().sum(), trips_df.shape[0], i))
+        logger.warning(
+            "%s of %s trips could not be scheduled after %s iterations"
+            % (choices.isnull().sum(), trips_df.shape[0], i)
+        )
 
         if failfix != FAILFIX_DROP_AND_CLEANUP:
-            raise RuntimeError("%s setting '%s' not enabled in settings" %
-                               (FAILFIX, FAILFIX_DROP_AND_CLEANUP))
+            raise RuntimeError(
+                "%s setting '%s' not enabled in settings"
+                % (FAILFIX, FAILFIX_DROP_AND_CLEANUP)
+            )
 
-        trips_df['failed'] = choices.isnull()
+        trips_df["failed"] = choices.isnull()
         trips_df = cleanup_failed_trips(trips_df)
         choices = choices.reindex(trips_df.index)
 
-    trips_df['depart'] = choices
+    trips_df["depart"] = choices
 
     assert not trips_df.depart.isnull().any()
 
