@@ -4,7 +4,6 @@ import logging
 
 from activitysim.core import inject
 
-
 logger = logging.getLogger(__name__)
 
 
@@ -13,4 +12,4 @@ def trips_merged(trips, tours):
     return inject.merge_tables(trips.name, tables=[trips, tours])
 
 
-inject.broadcast('tours', 'trips', cast_index=True, onto_on='tour_id')
+inject.broadcast("tours", "trips", cast_index=True, onto_on="tour_id")
