@@ -1,35 +1,29 @@
 # ActivitySim
 # See full license in LICENSE.txt.
-from builtins import range
-
-import logging
-import os
-import itertools
-import multiprocessing
 import gc as _gc
-import psutil
+import itertools
+import logging
+import multiprocessing
+import os
 import time
-
+from builtins import range
 from contextlib import contextmanager
 
 import numpy as np
 import pandas as pd
+import psutil
 
-from activitysim.core import util
-from activitysim.core import config
-from activitysim.core import inject
-from activitysim.core import simulate
-from activitysim.core import tracing
+from activitysim.core import config, inject, simulate, tracing, util
 
 logger = logging.getLogger(__name__)
 
 RAWARRAY = False
-DTYPE_NAME = 'float32'
+DTYPE_NAME = "float32"
 RESCALE = 1000
 
-DYNAMIC = 'dynamic'
-STATIC = 'static'
-TRACE = 'trace'
+DYNAMIC = "dynamic"
+STATIC = "static"
+TRACE = "trace"
 
 MEMO_STACK = []
 
@@ -52,7 +46,7 @@ def memo(tag, console=False, disable_gc=True):
     finally:
         elapsed_time = time.time() - t0
 
-        current_mem = (psutil.Process().memory_info().rss)
+        current_mem = psutil.Process().memory_info().rss
         marginal_mem = current_mem - previous_mem
         mem_str = f"net {util.GB(marginal_mem)} ({util.INT(marginal_mem)}) total {util.GB(current_mem)}"
 
@@ -73,6 +67,7 @@ class TVPBCache(object):
     """
     Transit virtual path builder cache for three zone systems
     """
+
     def __init__(self, network_los, uid_calculator, cache_tag):
 
         # lightweight until opened
@@ -88,13 +83,13 @@ class TVPBCache(object):
 
     @property
     def cache_path(self):
-        file_type = 'mmap'
-        return os.path.join(config.get_cache_dir(), f'{self.cache_tag}.{file_type}')
+        file_type = "mmap"
+        return os.path.join(config.get_cache_dir(), f"{self.cache_tag}.{file_type}")
 
     @property
     def csv_trace_path(self):
-        file_type = 'csv'
-        return os.path.join(config.get_cache_dir(), f'{self.cache_tag}.{file_type}')
+        file_type = "csv"
+        return os.path.join(config.get_cache_dir(), f"{self.cache_tag}.{file_type}")
 
     def cleanup(self):
         """
@@ -116,16 +111,17 @@ class TVPBCache(object):
 
         logger.debug(f"#TVPB CACHE write_static_cache df {data.shape}")
 
-        mm_data = np.memmap(self.cache_path,
-                            shape=data.shape,
-                            dtype=DTYPE_NAME,
-                            mode='w+')
+        mm_data = np.memmap(
+            self.cache_path, shape=data.shape, dtype=DTYPE_NAME, mode="w+"
+        )
         np.copyto(mm_data, data)
         mm_data._mmap.close()
         del mm_data
 
-        logger.debug(f"#TVPB CACHE write_static_cache wrote static cache table "
-                     f"({data.shape}) to {self.cache_path}")
+        logger.debug(
+            f"#TVPB CACHE write_static_cache wrote static cache table "
+            f"({data.shape}) to {self.cache_path}"
+        )
 
     def open(self):
         """
@@ -144,10 +140,12 @@ class TVPBCache(object):
             # multiprocessing usex preloaded fully_populated shared data buffer
             with memo("TVPBCache.open get_data_and_lock_from_buffers"):
                 data, _ = self.get_data_and_lock_from_buffers()
-            logger.info(f"TVPBCache.open {self.cache_tag} STATIC cache using existing data_buffers")
+            logger.info(
+                f"TVPBCache.open {self.cache_tag} STATIC cache using existing data_buffers"
+            )
         elif os.path.isfile(self.cache_path):
             # single process ought have created a precomputed fully_populated STATIC file
-            data = np.memmap(self.cache_path, dtype=DTYPE_NAME, mode='r')
+            data = np.memmap(self.cache_path, dtype=DTYPE_NAME, mode="r")
 
             # FIXME - why leave memmap open - maybe should copy since it will be read into memory when accessed anyway
             # mm_data = np.memmap(self.cache_path, dtype=DTYPE_NAME, mode='r')
@@ -156,15 +154,21 @@ class TVPBCache(object):
             # mm_data._mmap.close()
             # del mm_data
 
-            logger.info(f"TVPBCache.open {self.cache_tag} read fully_populated data array from mmap file")
+            logger.info(
+                f"TVPBCache.open {self.cache_tag} read fully_populated data array from mmap file"
+            )
         else:
-            raise RuntimeError(f"Pathbuilder cache not found. Did you forget to run initialize tvpb?"
-                               f"Expected cache file: {self.cache_path}")
+            raise RuntimeError(
+                f"Pathbuilder cache not found. Did you forget to run initialize tvpb?"
+                f"Expected cache file: {self.cache_path}"
+            )
 
         # create no-copy pandas DataFrame from numpy wrapped RawArray or Memmap buffer
         column_names = self.uid_calculator.set_names
         with memo("TVPBCache.open data.reshape"):
-            data = data.reshape((-1, len(column_names)))  # reshape so there is one column per set
+            data = data.reshape(
+                (-1, len(column_names))
+            )  # reshape so there is one column per set
 
         # data should be fully_populated and in canonical order - so we can assign canonical uid index
         with memo("TVPBCache.open uid_calculator.fully_populated_uids"):
@@ -219,31 +223,41 @@ class TVPBCache(object):
         buffer_size = util.iprod(self.uid_calculator.fully_populated_shape)
 
         csz = buffer_size * dtype.itemsize
-        logger.info(f"TVPBCache.allocate_data_buffer allocating data buffer "
-                    f"shape {shape} buffer_size {util.INT(buffer_size)} total size: {util.INT(csz)} ({util.GB(csz)})")
+        logger.info(
+            f"TVPBCache.allocate_data_buffer allocating data buffer "
+            f"shape {shape} buffer_size {util.INT(buffer_size)} total size: {util.INT(csz)} ({util.GB(csz)})"
+        )
 
         if shared:
-            if dtype_name == 'float64':
-                typecode = 'd'
-            elif dtype_name == 'float32':
-                typecode = 'f'
+            if dtype_name == "float64":
+                typecode = "d"
+            elif dtype_name == "float32":
+                typecode = "f"
             else:
-                raise RuntimeError("allocate_data_buffer unrecognized dtype %s" % dtype_name)
+                raise RuntimeError(
+                    "allocate_data_buffer unrecognized dtype %s" % dtype_name
+                )
 
             if RAWARRAY:
                 with memo("TVPBCache.allocate_data_buffer allocate RawArray"):
                     buffer = multiprocessing.RawArray(typecode, buffer_size)
-                logger.info(f"TVPBCache.allocate_data_buffer allocated shared multiprocessing.RawArray as buffer")
+                logger.info(
+                    f"TVPBCache.allocate_data_buffer allocated shared multiprocessing.RawArray as buffer"
+                )
             else:
                 with memo("TVPBCache.allocate_data_buffer allocate Array"):
                     buffer = multiprocessing.Array(typecode, buffer_size)
-                logger.info(f"TVPBCache.allocate_data_buffer allocated shared multiprocessing.Array as buffer")
+                logger.info(
+                    f"TVPBCache.allocate_data_buffer allocated shared multiprocessing.Array as buffer"
+                )
 
         else:
             buffer = np.empty(buffer_size, dtype=dtype)
             np.copyto(buffer, np.nan)  # fill with np.nan
 
-            logger.info(f"TVPBCache.allocate_data_buffer allocating non-shared numpy array as buffer")
+            logger.info(
+                f"TVPBCache.allocate_data_buffer allocating non-shared numpy array as buffer"
+            )
 
         return buffer
 
@@ -263,11 +277,13 @@ class TVPBCache(object):
 
         if os.path.isfile(self.cache_path):
             with memo("TVPBCache.load_data_to_buffer copy memmap"):
-                data = np.memmap(self.cache_path, dtype=DTYPE_NAME, mode='r')
+                data = np.memmap(self.cache_path, dtype=DTYPE_NAME, mode="r")
                 np.copyto(np_wrapped_data_buffer, data)
                 data._mmap.close()
                 del data
-            logger.debug(f"TVPBCache.load_data_to_buffer loaded data from {self.cache_path}")
+            logger.debug(
+                f"TVPBCache.load_data_to_buffer loaded data from {self.cache_path}"
+            )
         else:
             np.copyto(np_wrapped_data_buffer, np.nan)
             logger.debug(f"TVPBCache.load_data_to_buffer - saved cache file not found.")
@@ -279,7 +295,7 @@ class TVPBCache(object):
         -------
         either multiprocessing.Array and lock or multiprocessing.RawArray and None according to RAWARRAY
         """
-        data_buffers = inject.get_injectable('data_buffers', None)
+        data_buffers = inject.get_injectable("data_buffers", None)
         assert self.cache_tag in data_buffers  # internal error
         logger.debug(f"TVPBCache.get_data_and_lock_from_buffers")
         data_buffer = data_buffers[self.cache_tag]
@@ -297,6 +313,7 @@ class TapTapUidCalculator(object):
     """
     Transit virtual path builder TAP to TAP unique ID calculator for three zone systems
     """
+
     def __init__(self, network_los):
 
         self.network_los = network_los
@@ -304,13 +321,16 @@ class TapTapUidCalculator(object):
         # ensure that tap_df has been loaded
         # (during multiprocessing we are initialized before network_los.load_data is called)
         assert network_los.tap_df is not None
-        self.tap_ids = network_los.tap_df['TAP'].values
+        self.tap_ids = network_los.tap_df["TAP"].values
 
-        self.segmentation = \
-            network_los.setting('TVPB_SETTINGS.tour_mode_choice.tap_tap_settings.attribute_segments')
+        self.segmentation = network_los.setting(
+            "TVPB_SETTINGS.tour_mode_choice.tap_tap_settings.attribute_segments"
+        )
 
         # e.g. [(0, 'AM', 'walk'), (0, 'AM', 'walk')...]) for attributes demographic_segment, tod, and access_mode
-        self.attribute_combination_tuples = list(itertools.product(*list(self.segmentation.values())))
+        self.attribute_combination_tuples = list(
+            itertools.product(*list(self.segmentation.values()))
+        )
 
         # ordinalizers - for mapping attribute values to canonical ordinal values for uid computation
         # (pandas series of ordinal position with attribute value index (e.g. map tod value 'AM' to 0, 'MD' to 1,...)
@@ -319,13 +339,17 @@ class TapTapUidCalculator(object):
         for k, v in self.segmentation.items():
             self.ordinalizers[k] = pd.Series(range(len(v)), index=v)
         # orig/dest go last so all rows in same 'skim' end up with adjacent uids
-        self.ordinalizers['btap'] = pd.Series(range(len(self.tap_ids)), index=self.tap_ids)
-        self.ordinalizers['atap'] = self.ordinalizers['btap']
+        self.ordinalizers["btap"] = pd.Series(
+            range(len(self.tap_ids)), index=self.tap_ids
+        )
+        self.ordinalizers["atap"] = self.ordinalizers["btap"]
 
         # for k,v in self.ordinalizers.items():
         #     print(f"\ordinalizer {k}\n{v}")
 
-        spec_name = self.network_los.setting(f'TVPB_SETTINGS.tour_mode_choice.tap_tap_settings.SPEC')
+        spec_name = self.network_los.setting(
+            f"TVPB_SETTINGS.tour_mode_choice.tap_tap_settings.SPEC"
+        )
         self.set_names = list(simulate.read_model_spec(file_name=spec_name).columns)
 
     @property
@@ -379,7 +403,9 @@ class TapTapUidCalculator(object):
                 uid = uid * cardinality + np.asanyarray(df[name].map(ordinalizer))
             else:
                 # otherwise it should be in scalar_attributes
-                assert name in scalar_attributes, f"attribute '{name}' not found in df.columns or scalar_attributes."
+                assert (
+                    name in scalar_attributes
+                ), f"attribute '{name}' not found in df.columns or scalar_attributes."
                 uid = uid * cardinality + ordinalizer.at[scalar_attributes[name]]
 
         return uid
@@ -403,8 +429,8 @@ class TapTapUidCalculator(object):
         num_taps = len(self.tap_ids)
         od_choosers_df = pd.DataFrame(
             data={
-                'btap': np.repeat(self.tap_ids, num_taps),
-                'atap': np.tile(self.tap_ids, num_taps)
+                "btap": np.repeat(self.tap_ids, num_taps),
+                "atap": np.tile(self.tap_ids, num_taps),
             }
         )
         od_choosers_df.index = self.get_unique_ids(od_choosers_df, scalar_attributes)
@@ -430,7 +456,10 @@ class TapTapUidCalculator(object):
 
             # attribute_value_tuple is an tuple of attribute values - e.g. (0, 'AM', 'walk')
             # build dict of attribute name:value pairs - e.g. {'demographic_segment': 0, 'tod': 'AM', })
-            scalar_attributes = {name: value for name, value in zip(attribute_names, attribute_value_tuple)}
+            scalar_attributes = {
+                name: value
+                for name, value in zip(attribute_names, attribute_value_tuple)
+            }
 
             yield scalar_attributes
 
@@ -439,5 +468,5 @@ class TapTapUidCalculator(object):
         attribute_tuples = self.attribute_combination_tuples
         x = [list(t) for t in attribute_tuples]
         df = pd.DataFrame(data=x, columns=attribute_names)
-        df.index.name = 'offset'
+        df.index.name = "offset"
         return df
